"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContainerBuilder = void 0;
const revane_ioc_1 = require("revane-ioc");
const path_1 = require("path");
class ContainerBuilder {
    constructor(commands) {
        this.basePackagePath = process.cwd();
        console.log(this.basePackagePath);
        this.options = new revane_ioc_1.Options(process.cwd(), [
            new revane_ioc_1.ComponentScanExtension(),
            new revane_ioc_1.BeanFactoryExtension(),
            new revane_ioc_1.LoggingExtension(),
            new revane_ioc_1.SchedulingExtension(null)
        ]);
        this.commands = commands;
    }
    componentScan(path, excludeFilters, includeFilters) {
        this.ensureLoaderOptions();
        console.log(this.absolutePath(path));
        this.options.loaderOptions.push(new revane_ioc_1.ComponentScanLoaderOptions(this.absolutePath(path), excludeFilters, includeFilters));
    }
    disableAutoConfiguration() {
        this.options.autoConfiguration = false;
    }
    basePackage(path) {
        this.basePackagePath = path;
        this.options.basePackage = path;
    }
    xmlFile(file) {
        this.ensureLoaderOptions();
        this.options.loaderOptions.push(new revane_ioc_1.XmlFileLoaderOptions(this.absolutePath(file)));
    }
    jsonFile(file) {
        this.ensureLoaderOptions();
        this.options.loaderOptions.push(new revane_ioc_1.JsonFileLoaderOptions(this.absolutePath(file)));
    }
    noRedefinition(noRedefinition) {
        this.options.noRedefinition = noRedefinition;
    }
    configurationDir(path) {
        this.options.configuration = {
            directory: path,
            required: false,
            disabled: false
        };
    }
    async build() {
        for (const command of this.commands) {
            this[command.type](...command.args);
        }
        if (this.options.autoConfiguration == null) {
            this.options.autoConfiguration = true;
        }
        const container = new revane_ioc_1.default(this.options);
        await container.initialize();
        return container;
    }
    ensureLoaderOptions() {
        if (!this.options.loaderOptions) {
            this.options.loaderOptions = [];
        }
    }
    absolutePath(path) {
        if (path.startsWith('.')) {
            return path_1.join(this.basePackagePath, path);
        }
        return path;
    }
}
exports.ContainerBuilder = ContainerBuilder;
