"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerBuilder = void 0;
const revane_fastify_1 = require("revane-fastify");
class ServerBuilder {
    constructor(optionCommands, commands) {
        this.options = {};
        this.optionCommands = optionCommands;
        this.commands = commands;
    }
    container(container) {
        this.revaneIOC = container;
        return this;
    }
    register(id, options) {
        this.server.register(id, options);
    }
    registerControllers() {
        this.server.registerControllers();
    }
    setErrorHandler(id) {
        this.server.setErrorHandler(id);
    }
    setNotFoundHandler(id) {
        this.server.setNotFoundHandler(id);
    }
    ready(handler) {
        this.server.ready(handler);
    }
    silent(isSilent) {
        this.options.silent = isSilent;
    }
    async build() {
        if (this.commands.length === 0) {
            return Promise.resolve(null);
        }
        this.processComamands(this.optionCommands);
        this.createServer();
        this.processComamands(this.commands);
        await this.server.listen('configuration');
        return this.server;
    }
    processComamands(commands) {
        for (const command of commands) {
            this[command.type](...command.args);
        }
    }
    createServer() {
        this.server = revane_fastify_1.revaneFastify(this.options, this.revaneIOC.getContext());
    }
}
exports.ServerBuilder = ServerBuilder;
